Package: MALDIquant
Version: 1.22.3
Date: 2024-08-19
Title: Quantitative Analysis of Mass Spectrometry Data
Authors@R: c(
    person(
        given = "Sebastian", family = "Gibb",
        email="mail@sebastiangibb.de",
        comment=c(ORCID="0000-0001-7406-4443"),
        role = c("aut", "cre")
    ),
    person(
        given = "Korbinian", family = "Strimmer",
        comment=c(ORCID="0000-0001-7917-2056"),
        role="ths"
    ),
    person(given = "Sigurdur", family = "Smarason", role = "ctb"),
    person(
        given = "Laurent", family = "Gatto",
        email = "laurent.gatto@uclouvain.be",
        comment = c(ORCID = "0000-0002-1520-2268"),
        role = "ctb"
    ),
    person(given = "Paolo", family = "Inglese", role = "ctb"))
Depends: R (>= 4.0.0), methods
Imports: parallel
Suggests: knitr, testthat (>= 0.8)
Description: A complete analysis pipeline for matrix-assisted laser
        desorption/ionization-time-of-flight (MALDI-TOF) and other
        two-dimensional mass spectrometry data. In addition to commonly
        used plotting and processing methods it includes distinctive
        features, namely baseline subtraction methods such as
        morphological filters (TopHat) or the statistics-sensitive
        non-linear iterative peak-clipping algorithm (SNIP), peak
        alignment using warping functions, handling of replicated
        measurements as well as allowing spectra with different
        resolutions.
License: GPL (>= 3)
URL: https://strimmerlab.github.io/software/maldiquant/,
        https://github.com/sgibb/MALDIquant/
BugReports: https://github.com/sgibb/MALDIquant/issues/
LazyLoad: yes
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2024-08-19 20:58:22 UTC; sebastian
Author: Sebastian Gibb [aut, cre] (<https://orcid.org/0000-0001-7406-4443>),
  Korbinian Strimmer [ths] (<https://orcid.org/0000-0001-7917-2056>),
  Sigurdur Smarason [ctb],
  Laurent Gatto [ctb] (<https://orcid.org/0000-0002-1520-2268>),
  Paolo Inglese [ctb]
Maintainer: Sebastian Gibb <mail@sebastiangibb.de>
Repository: CRAN
Date/Publication: 2024-08-19 23:00:03 UTC
